#include <Keyboard.h>

const int buttonPin = 2; // Pin connected to the button
int buttonState = 0;     // Variable to store button state
int lastButtonState = HIGH; // To track changes in button state
bool autoSaveEnabled = false; // Flag to track if autosave is enabled

unsigned long previousMillis = 0; // For timing the autosave interval
const unsigned long interval = 300000; // 5 minutes in milliseconds

void setup() {
  pinMode(buttonPin, INPUT_PULLUP); // Set the button pin as input with internal pull-up
  Keyboard.begin();                 // Start the USB keyboard functionality
}

void loop() {
  // Read the current button state
  buttonState = digitalRead(buttonPin);

  // Check for a button press (state change from HIGH to LOW)
  if (buttonState == LOW && lastButtonState == HIGH) {
    delay(50); // Debounce delay
    if (digitalRead(buttonPin) == LOW) { // Confirm button press
      autoSaveEnabled = !autoSaveEnabled; // Toggle autosave state
      delay(500); // Prevent rapid toggling
    }
  }
  lastButtonState = buttonState; // Update last button state

  // If autosave is enabled, check if it's time to send the save command
  if (autoSaveEnabled) {
    unsigned long currentMillis = millis();
    if (currentMillis - previousMillis >= interval) {
      previousMillis = currentMillis; // Update the last save time
      sendSaveCommand();
    }
  }
}

void sendSaveCommand() {
  Keyboard.press(KEY_LEFT_CTRL); // Hold down the Ctrl key
  Keyboard.press('s');           // Press the 'S' key
  delay(100);                    // Short delay to ensure the key press is registered
  Keyboard.releaseAll();         // Release all keys
}
